==> GameTools-0.1.2b3.tar.gz: GameTools-0.1.2b3/README.md <==
![Version](https://img.shields.io/badge/Version-0.1.2-green) ![Status](https://img.shields.io/badge/Status-Operational-mint) ![issues](https://img.shields.io/github/issues/spidertyler2005/GameTools)

# GameTools

GameTools is a collection of packages that helps you create your game.

## Features
|Feature|Description|State|
|:--:|:--:|:--:|
|Templates|Templates make game creation easier by allowing you to write less code.|:white_check_mark:|
|DeltaTime Calculator|Calculates the deltaTime from the previous call of the function|:white_check_mark:|
|Messaging System|Have the ability to send messages and have functions listen to those Messages via a decorator -> ``@recv_Message("Message Name")``|:white_check_mark:|
|Entity System|The ability to create entitys|:memo:|
|UI System|A proper game Ui System is essentially for any menu in a game.|:black_large_square:|

:memo: -> started
:white_check_mark: -> finished or satisfactory
:red_circle: -> broken
:black_large_square: -> not started

---

## Getting Started

### Installation
 in your terminal run `python -m pip install GameTools-spidertyler2005`.Alternatively, you can download the source directly and throw it into your project.

### examples
If you look into Testing.py you can see me playing around with everything. There are also examples in the docs

### Documentation
Documentation can be found under the wiki tab in github.

---

## Other Information

### licensing information:
  We operate with an MIT liscense which can be found in
  [LICENSE.txt](LICENSE.txt)

==> GameTools-0.1.3.tar.gz: GameTools-0.1.3/README.md <==
![Version](https://img.shields.io/badge/Version-0.1.3-green) ![Status](https://img.shields.io/badge/Status-Operational-mint) ![issues](https://img.shields.io/github/issues/spidertyler2005/GameTools)

# GameTools

GameTools is a collection of packages that helps you create your game.

## Features
|Feature|Description|State|
|:--:|:--:|:--:|
|Templates|Templates make game creation easier by allowing you to write less code.|:white_check_mark:|
|DeltaTime Calculator|Calculates the deltaTime from the previous call of the function|:white_check_mark:|
|Messaging System|Have the ability to send messages and have functions listen to those Messages via a decorator -> ``@recv_Message("Message Name")``|:white_check_mark:|
|Entity System|The ability to create entitys|:memo:|
|UI System|A proper game Ui System is essentially for any menu in a game.|:black_large_square:|

:memo: -> started
:white_check_mark: -> finished or satisfactory
:red_circle: -> broken
:black_large_square: -> not started

---

## Getting Started

### Installation
 in your terminal run `python -m pip install GameTools`.Alternatively, you can download the source directly and throw it into your project.

### examples
If you look into src/Testing.py you can see me playing around with everything. There are also examples in the docs

### Documentation
Documentation can be found under the wiki tab in github.

---

## Other Information

### licensing information:
  We operate with an MIT liscense which can be found in
  [LICENSE.txt](LICENSE.txt)
